diff mcabber/src/main.c @ 848:a9161d2dc414

Introduce special buffer stuff Update roster and commands: add support for a new "special" kind of buffer. A special buffer "[status]" is automatically created at startup.
author Mikael Berthe <mikael@lilotux.net>
date Mon, 08 May 2006 23:45:58 +0200
parents 04edcb6d7ee3
children da03534e46c7
line wrap: on
line diff
--- a/mcabber/src/main.c	Mon May 08 22:38:30 2006 +0200
+++ b/mcabber/src/main.c	Mon May 08 23:45:58 2006 +0200
@@ -252,8 +252,9 @@
       }
   }
 
   /* Initialize commands system */
   cmd_init();
+  roster_init();
   /* Initialize charset */
   scr_InitLocaleCharSet();
@@ -252,8 +252,9 @@
   }
 
-  /* Initialize commands system */
+  /* Initialize commands system and roster */
   cmd_init();